@@ -3,8 +3,9 @@
 #' `r lifecycle::badge('stable')`
 #'
 #' Plot the posterior distribution of all latent parameters using a dataframe of posterior draws from a `causact_graph` model.
-#' @param drawsDF the dataframe output of `dag_greta(mcmc=TRUE)` where each column is a parameter and each row a single draw from a representative sample.
+#' @param drawsDF the dataframe output of `dag_numpyro(mcmc=TRUE)` where each column is a parameter and each row a single draw from a representative sample.
 #' @param densityPlot If `TRUE`, each parameter gets its own density plot.  If `FALSE` (recommended usage), parameters are grouped into facets based on whether they share the same prior or not.  10 and 90 percent credible intervals are displayed for the posterior distributions.
+#' @param abbrevLabels If `TRUE`, long labels on the plot are abbreviated to 10 characters.  If `FALSE` the entire label is used.
 #' @return a credible interval plot of all latent posterior distribution parameters.
 #' @examples
 #' # A simple example
@@ -14,9 +15,8 @@
 #' posteriorDF %>%
 #' dagp_plot(densityPlot = TRUE)
 #'
-#' # More complicated example requiring 'greta'
+#' # More complicated example requiring 'numpyro'
 #' \dontrun{
-#' library(greta)
 #' # Create a 2 node graph
 #' graph = dag_create() %>%
 #'   dag_node("Get Card","y",
@@ -28,7 +28,7 @@
 #' graph %>% dag_render()
 #'
 #' # below requires Tensorflow installation
-#' drawsDF = graph %>% dag_greta(mcmc=TRUE)
+#' drawsDF = graph %>% dag_numpyro(mcmc=TRUE)
 #' drawsDF %>% dagp_plot()
 #' }
 #'
@@ -64,65 +64,80 @@
 #' graph %>% dag_render()
 #' \dontrun{
 #' # below requires Tensorflow installation
-#' drawsDF = graph %>% dag_greta(mcmc=TRUE)
+#' drawsDF = graph %>% dag_numpyro(mcmc=TRUE)
 #' drawsDF %>% dagp_plot()
 #' }
 #' @importFrom dplyr bind_rows filter group_by
 #' @importFrom rlang is_empty UQ enexpr enquo expr_text quo_name eval_tidy .data
-#' @export
-#' @importFrom ggplot2 ggplot geom_density facet_wrap aes theme_minimal theme scale_alpha_continuous guides labs geom_segment element_blank
+#' @importFrom ggplot2 ggplot geom_density facet_wrap aes theme_minimal theme scale_alpha_continuous guides labs geom_segment element_blank after_stat
 #' @importFrom tidyr gather
 #' @importFrom cowplot plot_grid
 #' @importFrom stats quantile
+#' @importFrom lifecycle badge
 #' @export
 
 
-dagp_plot = function(drawsDF,densityPlot = FALSE) { # case where untidy posterior draws are provided
-  ..scaled.. <- q95 <- reasonableIntervalWidth <- credIQR <- shape <- param <- NULL ## place holder to pass devtools::check
+dagp_plot = function(drawsDF,densityPlot = FALSE, abbrevLabels = FALSE) { # case where untidy posterior draws are provided
+  q95 <- density <- reasonableIntervalWidth <- credIQR <- shape <- param <- NULL ## place holder to pass devtools::check
+
   if (densityPlot == TRUE) {
-    plot = drawsDF %>% gather() %>%
-      ggplot(aes(x = value, y = ..scaled..)) +
-      geom_density(aes(fill = key)) +
-      facet_wrap( ~ key, scales = "free_x") +
-      theme_minimal() +
-      theme(legend.position = "none")
+    if (abbrevLabels) {  ## shorten labels if desired
+      drawsDF = drawsDF %>%
+        tidyr::gather() %>%
+        dplyr::mutate(key = abbreviate(key, minlength = 10))} else {
+          drawsDF = drawsDF %>%
+            tidyr::gather()
+        }
+    plot = drawsDF %>% ## start with tidy draws
+      ggplot2::ggplot(ggplot2::aes(x = value,
+                          y = ggplot2::after_stat(density))) +
+      ggplot2::geom_density(ggplot2::aes(fill = key)) +
+      ggplot2::facet_wrap( ~ key, scales = "free_x") +
+      ggplot2::theme_minimal() +
+      ggplot2::theme(legend.position = "none")
 
     plot
   } else { # case where tidy posterior draws are provided
     plotList = list()
     ## filter out NA's like from LKJ prior (we do not know how to plot this)
     tryCatch({
+      if (abbrevLabels) {  ## shorten labels if desired
+        drawsDF = drawsDF %>%
+          addPriorGroups() %>%
+          dplyr::mutate(param = abbreviate(param, minlength = 10))} else {
+            drawsDF = drawsDF %>%
+              addPriorGroups()
+          }
       drawsDF = drawsDF %>%
-      addPriorGroups() %>%
-        mutate(priorGroup = ifelse(is.na(priorGroup),999999,priorGroup)) %>%
+        dplyr::mutate(priorGroup = ifelse(is.na(priorGroup),999999,priorGroup)) %>%
       dplyr::filter(!is.na(priorGroup)) ##if try works, erase this line
     priorGroups = unique(drawsDF$priorGroup)
     numPriorGroups = length(priorGroups)
     for (i in 1:numPriorGroups) {
-      df = drawsDF %>% filter(priorGroup == priorGroups[i])
+      df = drawsDF %>% dplyr::filter(priorGroup == priorGroups[i])
 
       # create one plot per group
       # groups defined as params with same prior
-      plotList[[i]] = df %>% group_by(param) %>%
-        summarize(q05 = stats::quantile(value,0.05),
+      plotList[[i]] = df %>% dplyr::group_by(param) %>%
+        dplyr::summarize(q05 = stats::quantile(value,0.05),
                   q25 = stats::quantile(value,0.55),
                   q45 = stats::quantile(value,0.45),
                   q50 = stats::quantile(value,0.50),
                   q55 = stats::quantile(value,0.55),
                   q75 = stats::quantile(value,0.75),
                   q95 = stats::quantile(value,0.95)) %>%
-        mutate(credIQR = q75 - q25) %>%
-        mutate(reasonableIntervalWidth = 1.5 * stats::quantile(credIQR,0.75)) %>%
-        mutate(alphaLevel = ifelse(.data$credIQR > .data$reasonableIntervalWidth, 0.3,1)) %>%
-        arrange(alphaLevel,.data$q50) %>%
-        mutate(param = factor(param, levels = param)) %>%
-        ggplot(aes(y = param, yend = param)) +
-        geom_segment(aes(x = q05, xend = q95, alpha = alphaLevel), size = 4, color = "#5f9ea0") +
-        geom_segment(aes(x = q45, xend = q55, alpha = alphaLevel), size = 4, color = "#11114e") +
-        scale_alpha_continuous(range = c(0.6,1))  +
-        guides(alpha = "none") +
-        theme_minimal(12) +
-        labs(y = element_blank(),
+        dplyr::mutate(credIQR = q75 - q25) %>%
+        dplyr::mutate(reasonableIntervalWidth = 1.5 * stats::quantile(credIQR,0.75)) %>%
+        dplyr::mutate(alphaLevel = ifelse(.data$credIQR > .data$reasonableIntervalWidth, 0.3,1)) %>%
+        dplyr::arrange(alphaLevel,.data$q50) %>%
+        dplyr::mutate(param = factor(param, levels = param)) %>%
+        ggplot2::ggplot(ggplot2::aes(y = param, yend = param)) +
+        ggplot2::geom_segment(ggplot2::aes(x = q05, xend = q95, alpha = alphaLevel), linewidth = 4, color = "#5f9ea0") +
+        ggplot2::geom_segment(ggplot2::aes(x = q45, xend = q55, alpha = alphaLevel), linewidth = 4, color = "#11114e") +
+        ggplot2::scale_alpha_continuous(range = c(0.6,1))  +
+        ggplot2::guides(alpha = "none") +
+        ggplot2::theme_minimal(12) +
+        ggplot2::labs(y = ggplot2::element_blank(),
              x = "parameter value",
              caption = ifelse(i == numPriorGroups,"Credible Intervals - 10% (dark) & 90% (light)",""))
 
